@@ -45,6 +45,7 @@ from .site import (
 from .file import TrackedFile, Revision, DefaultFileMap
 from .kitsu import KitsuAPIWrapper, KitsuBindings, KitsuUsers, KitsuTasks
 from .dependency import DependencyTemplates
+from .mytasks import MyTasks
 
 
 class LoginPageWidget(CustomPageWidget):
@@ -218,6 +219,18 @@ class GotoBookmarks(flow.Action):
         )
 
 
+class GoToMyTasks(flow.Action):
+    ICON = ("icons.gui", "star")
+
+    def needs_dialog(self):
+        return False
+    
+    def run(self, button):
+        return self.get_result(
+            goto=self.root().project().mytasks.oid()
+        )
+
+
 class WorkingSiteChoiceValue(flow.values.ChoiceValue):
 
     _parent = flow.Parent()
@@ -385,8 +398,10 @@ class KitsuConfig(flow.Object):
 
         for pattern in patterns:
             pattern = pattern.replace(' ', '')
-            if not fnmatch.fnmatch(file_name, pattern):
-                return False
+            if fnmatch.fnmatch(file_name, pattern):
+                return True
+        
+        return False
     
     def summary(self):
         if not self.configured.get():
@@ -550,6 +565,8 @@ class Admin(flow.Object):
 class Project(flow.Object):
 
     log_out_action = flow.Child(LogOut).ui(label="Log out")
+    goto_my_tasks = flow.Child(GoToMyTasks).ui(label="My Tasks")
+    mytasks = flow.Child(MyTasks).ui(hidden=True)
 
     user = flow.Child(UserProfile)
     asset_lib = flow.Child(Assets).ui(expanded=True)
