@@ -1,3 +1,4 @@
+import pprint
 import gazu
 import os
 import fnmatch
@@ -271,6 +272,15 @@ class KitsuAPIWrapper(flow.Object):
         
         return task
     
+    def get_assign_tasks(self):
+        return gazu.user.all_tasks_to_do()
+
+    def get_done_tasks(self):
+        return gazu.user.all_done_tasks()
+
+    def get_all_comments_for_task(self, task_id):
+        return gazu.task.all_comments_for_task(task_id)
+
     def get_shot_task(self, sequence_name, shot_name, task_type_name):
         task = None
         shot = self.get_shot_data(shot_name, sequence_name)
@@ -289,8 +299,10 @@ class KitsuAPIWrapper(flow.Object):
         
         return status
     
-    def get_task_statutes(self):
+    def get_task_statutes(self, short_name=False):
         task_statuses = gazu.task.all_task_statuses()
+        if short_name:
+            return [ts['short_name'] for ts in task_statuses]
         return [ts['name'] for ts in task_statuses]
     
     def get_task_current_status(self, entity, task_type_name):
@@ -301,13 +313,13 @@ class KitsuAPIWrapper(flow.Object):
         
         return task['task_status']['name']
     
-    def get_shot_task_types(self, entity_type=None):
+    def get_task_types(self, entity_type=None):
         types = gazu.task.all_task_types()
-        types =  [
-            t['name'] for t in types
-            if entity_type is None or t['for_entity'] == entity_type
-        ]
-        return types
+        if entity_type == 'Shot':
+            return [t['name'] for t in types if t['for_entity'] == 'Shot']
+        elif entity_type == 'Asset':
+            return [t['name'] for t in types if t['for_entity'] == 'Asset']
+        return [t['for_entity']+' - '+t['name'] for t in types]
     
     def get_user(self, project_user_name=None):
         if project_user_name is None:
