@@ -1397,9 +1397,14 @@ class WorkingSite(Site):
     site_environment = flow.Child(SiteEnvironment)
 
     with flow.group('AfterEffects settings'):
-        ae_render_settings     = flow.Param().ui(label='Render settings')
-        ae_output_module_movie = flow.Param().ui(label='Output module (movie)')
-        ae_output_module_audio = flow.Param().ui(label='Output module (audio)')
+        ae_render_settings_templates = flow.HashParam().ui(
+            label='Render settings templates')
+        ae_output_module_templates   = flow.HashParam().ui(
+            label='Output module templates')
+        ae_output_module_audio       = flow.Param().ui(
+            label='Audio output module template')
+        ae_comp_name_patterns        = flow.OrderedStringSetParam().ui(
+            label='Composition name patterns')
 
     def compute_child_value(self, child_value):
         if child_value is self.root_folder:
