@@ -41,7 +41,7 @@ class Task(Entity):
         action_submenus=True,
         items_action_submenus=True
     )
-    active_file = flow.Connection(TrackedFile).ui(hidden=True)
+    primary_files = Property().ui(hidden=True)
     priority_actions  = Property().ui(hidden=True)
 
     @classmethod
@@ -66,7 +66,6 @@ class Task(Entity):
             icon = self.icon_large.get()
         
         return icon and tuple(icon)
-
     
     def get_display_name(self):
         name = self.display_name.get()
@@ -74,6 +73,23 @@ class Task(Entity):
             name = self.name()
         return name
     
+    def get_primary_files(self):
+        '''
+        Returns the oids of the primary files of this task as a list.
+        '''
+        primary_names = [n.replace('.', '_') for n in self.get_primary_file_names() or []]
+        mapped_names = self.files.mapped_names()
+        primary_files = []
+        
+        for n in primary_names:
+            if n in mapped_names:
+                primary_files.append(self.files[n].oid())
+        
+        return primary_files
+    
+    def get_primary_file_names(self):
+        return self.primary_files.get() or None
+    
     def _fill_ui(self, ui):
         ui['custom_page'] = 'libreflow.baseflow.ui.task.TaskPageWidget'
 
@@ -241,6 +257,15 @@ class ManagedTask(Task):
         
         return color
     
+    def get_primary_file_names(self):
+        names = super(ManagedTask, self).get_primary_file_names()
+
+        if names is None:
+            tm = self.root().project().get_task_manager()
+            names = tm.get_task_primary_file_names(self.name())
+        
+        return names
+    
     def _get_assigned_users(self, subtask_name=None):
         if subtask_name is None:
             names = self.assigned_users.get() or []
