@@ -351,6 +351,82 @@ class EditableTaskColor(flow.values.Value):
 # -------------------------
 
 
+class KitsuTaskName(flow.values.SessionValue):
+
+    DEFAULT_EDITOR = 'choice'
+
+    def choices(self):
+        return sorted(self.root().project().kitsu_api().get_task_types())
+    
+    def update_default_value(self):
+        choices = self.choices()
+        if choices:
+            self._value = choices[0]
+        self.touch()
+
+
+class AddKitsuTaskNameAction(flow.Action):
+
+    ICON = ('icons.gui', 'plus-sign-in-a-black-circle')
+
+    kitsu_task = flow.SessionParam(None, KitsuTaskName)
+
+    _value = flow.Parent()
+
+    def get_buttons(self):
+        self.kitsu_task.update_default_value()
+        return ['Add', 'Cancel']
+    
+    def allow_context(self, context):
+        return context and context.endswith('.inline')
+    
+    def run(self, button):
+        if button == 'Cancel':
+            return
+        
+        self._value.add(self.kitsu_task.get().split(' - ')[1], 0)
+
+
+class ExistingKitsuTaskNames(flow.values.SessionValue):
+
+    DEFAULT_EDITOR = 'multichoice'
+    STRICT_CHOICES = False
+
+    _task_names = flow.Parent(2)
+
+    def choices(self):
+        return self._task_names.get()
+
+
+class RemoveKitsuTaskNameAction(flow.Action):
+
+    ICON = ('icons.gui', 'minus-button')
+
+    kitsu_tasks = flow.SessionParam(list, ExistingKitsuTaskNames)
+
+    _value = flow.Parent()
+
+    def get_buttons(self):
+        self.kitsu_tasks.revert_to_default()
+        return ['Confirm', 'Cancel']
+    
+    def allow_context(self, context):
+        return context and context.endswith('.inline')
+    
+    def run(self, button):
+        if button == 'Cancel':
+            return
+        
+        for name in self.kitsu_tasks.get():
+            self._value.remove(name)
+
+
+class EditableKitsuTaskNames(flow.values.OrderedStringSetValue):
+
+    add_action = flow.Child(AddKitsuTaskNameAction).ui(label='Add')
+    remove_action = flow.Child(RemoveKitsuTaskNameAction).ui(label='Remove')
+
+
 class EditDefaultTaskFile(flow.Action):
     """
     Allows to edit a default task's file.
@@ -670,7 +746,8 @@ class DefaultTask(flow.Object):
     color        = flow.Param(None, EditableTaskColor)
     icon         = flow.Param()
     files        = flow.Child(DefaultTaskFiles).ui(expanded=True)
-    default_edit_file = flow.Param()
+    primary_files = flow.Param()
+    kitsu_tasks   = flow.OrderedStringSetParam(EditableKitsuTaskNames).ui(editable=False)
     priority_actions  = flow.Param()
 
     subtasks     = flow.OrderedStringSetParam()
@@ -697,6 +774,16 @@ class DefaultTask(flow.Object):
         
         return tuple(icon)
     
+    def get_primary_file_names(self):
+        names = self.primary_files.get()
+
+        if not names:
+            mgr = self.root().project().get_task_manager()
+            tp = mgr.task_templates[self.template.get()]
+            names = tp.primary_files.get()
+        
+        return names or None
+    
     def get_display_name(self):
         return self.display_name.get()
 
@@ -768,6 +855,7 @@ class TaskTemplate(flow.Object):
     color = flow.Param(None, EditableTaskColor)
     icon  = flow.Param(('icons.gui', 'cog-wheel-silhouette'))
     files = flow.Child(DefaultFiles).ui(expanded=True)
+    primary_files = flow.Param()
 
 
 class TaskTemplates(flow.Map):
@@ -990,6 +1078,10 @@ class TaskManager(flow.Object):
         dt = self.default_tasks[task_name]
         return dt.get_display_name()
     
+    def get_task_primary_file_names(self, task_name):
+        dt = self.default_tasks[task_name]
+        return dt.get_primary_file_names()
+    
     def get_template_default_tasks(self, template_name):
         return [
             dt for dt in self.default_tasks.mapped_items()
