@@ -4,113 +4,119 @@ from kabaret import flow
 from kabaret.flow_entities.entities import Entity, EntityCollection
 
 
-class CustomEntityCollection(EntityCollection):
-    '''
-    This class provides add and remove operators, and allows type injections
-    on elements whose type is derived from its mapped_type (returned by
-    `mapped_type()`).
-    '''
-    _mapped_types = flow.HashParam()
+class CustomEntity(Entity):
 
-    def get_property(self, entity_name, property_name):
-        value = (
-            self.get_entity_store()
-            .get_collection(self.collection_name())
-            .find_one(
-                {'name': entity_name},
-                { property_name: 1},
-            )
-        )
-        try:
-            return value[property_name]
-        except KeyError:
-            default = getattr(self._get_mapped_item_type(entity_name), property_name).get_default_value()
-            return default
+    def get_properties(self, *property_names):
+        return self._collection.get_properties(self.name(), *property_names)
 
-    def add(self, name, object_type=None):
-        '''
-        Adds an object to the map.
-        If provided, object_type must be a subclass of the map's mapped_type (returned by the
-        classmethod mapped_type())
-        '''
-        mapped_type = flow.injection.resolve(
-            self.mapped_type(), self
-        )
-        if object_type is None:
-            object_type = mapped_type
-        elif not issubclass(object_type, mapped_type):
-            raise TypeError(
-                'Cannot add %r of type %r to Map %r: not a subclass of %r' % (
-                    name, object_type, self.oid(), mapped_type
-                )
-            )
-        else:
-            # Resolve potential injections on provided object type
-            object_type = flow.injection.resolve(object_type, self)
 
-        if '.' in name:
-            raise TypeError(
-                'Invalid object name %r (it must be a valid attribute name).' % (name,))
-        try:
-            exec(name + '=None') in {}
-        except:
-            raise TypeError(
-                'Invalid object name %r (it must be a valid attribute name).' % (name,))
-        if name in dir(self):
-            raise ValueError(
-                'Cannot add an item "%r", this name is already defined in the class "%s" (%s).' %
-                (
-                    name, self.__class__.__name__, self._mng.oid()
-                )
-            )
-        if self.has_mapped_name(name):
-            raise ValueError(
-                'An item %r is already mapped in %r.' %
-                (
-                    name, self._mng.oid()
-                )
-            )
+# class CustomEntityCollection(EntityCollection):
+#     '''
+#     This class provides add and remove operators, and allows type injections
+#     on elements whose type is derived from its mapped_type (returned by
+#     `mapped_type()`).
+#     '''
+#     _mapped_types = flow.HashParam()
 
-        object_qualified_type_name = self._mng.get_qualified_type_name(
-            object_type)
+#     def get_property(self, entity_name, property_name):
+#         value = (
+#             self.get_entity_store()
+#             .get_collection(self.collection_name())
+#             .find_one(
+#                 {'name': entity_name},
+#                 { property_name: 1},
+#             )
+#         )
+#         try:
+#             return value[property_name]
+#         except KeyError:
+#             default = getattr(self._get_mapped_item_type(entity_name), property_name).get_default_value()
+#             return default
+
+#     def add(self, name, object_type=None):
+#         '''
+#         Adds an object to the map.
+#         If provided, object_type must be a subclass of the map's mapped_type (returned by the
+#         classmethod mapped_type())
+#         '''
+#         mapped_type = flow.injection.resolve(
+#             self.mapped_type(), self
+#         )
+#         if object_type is None:
+#             object_type = mapped_type
+#         elif not issubclass(object_type, mapped_type):
+#             raise TypeError(
+#                 'Cannot add %r of type %r to Map %r: not a subclass of %r' % (
+#                     name, object_type, self.oid(), mapped_type
+#                 )
+#             )
+#         else:
+#             # Resolve potential injections on provided object type
+#             object_type = flow.injection.resolve(object_type, self)
+
+#         if '.' in name:
+#             raise TypeError(
+#                 'Invalid object name %r (it must be a valid attribute name).' % (name,))
+#         try:
+#             exec(name + '=None') in {}
+#         except:
+#             raise TypeError(
+#                 'Invalid object name %r (it must be a valid attribute name).' % (name,))
+#         if name in dir(self):
+#             raise ValueError(
+#                 'Cannot add an item "%r", this name is already defined in the class "%s" (%s).' %
+#                 (
+#                     name, self.__class__.__name__, self._mng.oid()
+#                 )
+#             )
+#         if self.has_mapped_name(name):
+#             raise ValueError(
+#                 'An item %r is already mapped in %r.' %
+#                 (
+#                     name, self._mng.oid()
+#                 )
+#             )
+
+#         object_qualified_type_name = self._mng.get_qualified_type_name(
+#             object_type)
         
-        c = self.get_entity_store().get_collection(self.collection_name())
-        c.insert_one({'name': name})
-        self._mapped_types.set_key(name, object_qualified_type_name)
+#         c = self.get_entity_store().get_collection(self.collection_name())
+#         c.insert_one({'name': name})
+#         self._mapped_types.set_key(name, object_qualified_type_name)
 
-        # Reset collection cache to get newly created entry
-        self._document_cache = None
+#         # Reset collection cache to get newly created entry
+#         self._document_cache = None
 
-        return self.get_mapped(name)
+#         return self.get_mapped(name)
 
-    def remove(self, name):
-        self._mapped_types.del_key(name)
-        c = self.get_entity_store().get_collection(self.collection_name())
-        c.delete_one({'name': name})
+#     def remove(self, name):
+#         self._mapped_types.del_key(name)
+#         c = self.get_entity_store().get_collection(self.collection_name())
+#         c.delete_one({'name': name})
 
-    def _get_mapped_item_type(self, mapped_name):
-        '''
-        Returns the type of the given mapped item.
-        NB: The GUI assumes that the returned type is a subclass
-        of mapped_type().
+#     def _get_mapped_item_type(self, mapped_name):
+#         '''
+#         Returns the type of the given mapped item.
+#         NB: The GUI assumes that the returned type is a subclass
+#         of mapped_type().
 
-        '''
-        object_qualified_type_name = self._mapped_types.get_key(mapped_name)
-        try:
-            object_type = self._mng.qualified_type_name_to_type(
-                object_qualified_type_name
-            )
-        except ImportError:
-            mapped_type = flow.injection.resolve(
-                self.mapped_type(), self
-            )
-            logging.getLogger('kabaret.ui').debug(
-                'WARNING: unable to access type %r. Downgrading to map default type %r' % (
-                    object_qualified_type_name, mapped_type
-                )
-            )
-            object_type = mapped_type
-        return object_type
+#         '''
+#         object_qualified_type_name = self._mapped_types.get_key(mapped_name)
+#         try:
+#             object_type = self._mng.qualified_type_name_to_type(
+#                 object_qualified_type_name
+#             )
+#         except ImportError:
+#             mapped_type = flow.injection.resolve(
+#                 self.mapped_type(), self
+#             )
+#             logging.getLogger('kabaret.ui').debug(
+#                 'WARNING: unable to access type %r. Downgrading to map default type %r' % (
+#                     object_qualified_type_name, mapped_type
+#                 )
+#             )
+#             object_type = mapped_type
+#         return object_type
 
 
 class GlobalEntityCollection(EntityCollection):
@@ -264,6 +270,33 @@ class EntityView(EntityCollection):
             default = getattr(self._get_mapped_item_type(entity_name), property_name).get_default_value()
             return default
     
+    def get_properties(self, entity_name, *property_names):
+        '''
+        Returns the values of the given properties as a dict.
+
+        This method assumes that all the requested properties exist in this entity.
+        '''
+        doc = (
+            self.get_entity_store()
+            .get_collection(self.collection_name())
+            .find_one(
+                {"name": f'{self.oid()}/{entity_name}'},
+                {
+                    property_name: True
+                    for property_name in property_names
+                },
+            )
+        )
+        values = {}
+
+        for property_name in property_names:
+            try:
+                values[property_name] = doc[property_name]
+            except KeyError:
+                values[property_name] = getattr(self.mapped_type(), property_name).get_default_value()
+
+        return values
+    
     def _fill_row_cells(self, row, item):
         row['Name'] = item.name()
 
